<?php
# ########### #
# Adaptation  #
# SpipFactory #
# 13-10-2020  #
# ########### #

namespace Garradin;

require_once __DIR__ . '/_inc.php';
require_once PLUGIN_ROOT . '/lib/MPDF/vendor/autoload.php';

$session->requireAccess('compta', Membres::DROIT_ACCES);

$membres = new Membres;

qv(['id' => 'required|numeric']);
$id = (int) qg('id');

$f = $facture->get($id);


if (!$f)
{
	throw new UserException("Ce document n'existe pas.");
}

$moyen_paiement = $facture->getMoyenPaiement($f->moyen_paiement);

try
{
	if ($f->receveur_membre)
	{
		$c = $membres->get($f->receveur_id);
		foreach(['ville','code_postal','adresse'] as $v)
		{
//			if($c->$v == '')
			{
				$c->$v = '[A RENSEIGNER DANS LA FICHE MEMBRE]';
			}
		}
	}
	else
	{
		$c = $client->get($f->receveur_id);
	}
}
catch(UserException $e)
{
	$form->addError("Pas de document correspondant à cet id trouvée."); 
}

// Création du PDF

$pdf = new \Mpdf\Mpdf([
	'default_font_size' => 10,
	'default_font' => 'dejavusans',
]);
$pdf->SetAuthor($config->get('nom_asso'));

ob_start();

$doc = ($f->type_facture?'Cotisation':'Devis').' n°'.$f->numero;
$emission = date("d-m-Y");
$pdf->SetTitle($doc.' - '.$emission);

$asso =
	'<b>'.$config->get('nom_asso')."</b><br>".
	str_replace("\n", '<br>', $config->get('adresse_asso'))."<br>".
	(($t = $cfg->get('siret_asso'))?" Numéro RNA : $t<br>":'').
	(($t = $config->get('email_asso'))?"Email : $t<br>":'').
	(($t = $config->get('site_asso'))?"Site web : $t<br>":'').
	//	Mention légale loi 1901
	'<em><small>Association à but non lucratif<br>de droit français<br>régie par la loi du 1er juillet 1901</small><em>';

$receveur =
	'Reçu adressé au site :<br><br>'.
	'<b>'.$c->url.'</b><br>'.
	(($t = $c->email)?"Email : <b>".$t."</b><br><br>":'').
	'Le '.$emission;
	$email = $t;

$total = number_format($f->total, 2, ',', ' ');
$echeance = date('d/m/Y' ,$f->date_echeance);
$reglee = !$f->reglee?'En attente de règlement.':'Cette cotisation a été reglée.';
$footer = str_replace("\n", '<br>', $cfg->get('footer'));


//	Nom du site sans https:// ni extension
$site = stristr($c->url,".", true);	//	Supprime l'extension
$site = substr($site, 8);	// Supprime https://

echo <<<EOF
<!-- STYLE -->

<style>
    .titre {
	text-align: center;
	font-size: 8pt;
	position: absolute;
	top: 6mm;
	width: 180mm;
    }
    .h2 {
	margin: 25 20 0 20;
    }
    .h2 span {
	font-weight: bold;
	font-size: 15pt;
    }
    hr {
	margin: 5 0 20 0;
    }
    .adressage {
	font-size: 11pt;
    }
    .adressage td {
	width: 95mm;
	vertical-align: top;
    }

    .contenu td, .contenu th {
	vertical-align: top;
	padding: 8 10;
	margin : 0;
	border-collapse: collapse;
    }

//	Modification de taille des colonnes 
//	Pour accepter le commentaire
//	Dispense TVA
    .contenu tr th, .contenu tr td {
	text-align: right;
	width: 25%;	// 6%;
    }
    .contenu tr td:nth-child(1), .contenu tr th:nth-child(1) {
	text-align: left;
	width: 75%;	//	84%;
    }

    .contenu thead tr, .contenu tfoot tr {
	background-color: #CCE;
	border: 10px solid black;
    }
    .contenu tbody tr:nth-child(even) {
	background-color: #DDF;
    }

    footer {
	position: absolute;
	bottom: 0;
	margin: 14mm 0;
	font-size: 9pt;
    }

</style>

<!-- CONTENU -->
<img src="https://spipfactory.fr/IMG/logo/siteon0-2_cle8c4a15.png?1595767098" width="15%" />
<p class="titre">
<!-- $doc - Émis le $emission -->
</p>
<p>&nbsp;</p>

<table class="adressage">
    <tr>
	<td>$asso</td>
	<td>$receveur</td>
    </tr>
</table>

<br>

<div class="h2">
    <span>Contenu</span> - $doc
</div>
<hr>

<table class="contenu" width="100%">
    <thead>
	<tr>
	    <th>
		Désignations
	    </th>
	    <th>
		Prix
	    </th>
	</tr>
    </thead>
    <tbody>
EOF;

$i = 1;
foreach($f->contenu as $k=>$v)
{   
	echo '<tr><td>';
	echo str_replace("\n", '<br>', $v['designation']);
	echo '</td><td>';
	echo number_format($v['prix'], 2, ',', ' ').'€';
	echo '</td></tr>';
	$i++;
}
//	Modification prix (HT) pour respecter la compta des associations
echo <<<EOF
    </tbody>
    <tfoot>
	<tr>
		<td><h3>Total</h3>Net à payer</td>
		<td><b>$total €</b><br /><em><small>Dispense de TVA</small></em></td>
	</tr>
    </tfoot>
</table>


<footer>
    <div class="h2"><span>Détails</span></div>
    <hr>

<!--    $emission<br>-->
    $reglee
    Moyen de paiement : $moyen_paiement

    <p>
	$footer
    </p>

</footer>
EOF;


$html = ob_get_clean();
$pdf->WriteHTML($html);

if(qg('d') !== null)
{
	$t = \Mpdf\Output\Destination::DOWNLOAD;
}
//	Création du pdf physique
elseif(qg('m') !== null)
{
	$t = \Mpdf\Output\Destination::FILE;
}
else
{
	$t = \Mpdf\Output\Destination::INLINE;
}

if ($t !== \Mpdf\Output\Destination::FILE){
	$pdf->Output(    
	($f->type_facture?'Cotisation':'Devis').'_'.$f->numero.'_'.$site.'.pdf', $t);
	}
else{
	//	Ici on doit pouvoir aller directement dans le fichier message_cotisation.php en transmettant les bonnes variables.
	$pdf->Output('../../cotisations/'.$f->numero.'_'.$site.'.pdf', $t);
	echo '<h3>Cliquez sur le lien ci-dessous</h3><br />';
	echo '<a href="message_cotisation.php?id='.$f->receveur_id.'&numero='.$f->numero.'">Ici</a>';
}